@@ -65,11 +65,13 @@ for context in commands.keys():
                     params.append(f"<{title}>")
                 else:
                     params.append(f"[{title}]")
-            cmd_full = f"{name} {' '.join(params)}"
+            if len(params) > 0:
+                cmd_full = f"{name} {' '.join(params)}"
+            else:
+                cmd_full = f"{name}"
             max_length = max(max_length, len(cmd_full))
             usage_text[context].append((cmd_full, cmd.help_text))
     text = ''
     for i in usage_text[context]:
-        # FIXME: number of spacing dots here
-        text += '  ' + i[0].ljust(20, '.') + i[1] + '\n'
+        text += '  ' + i[0].ljust(max_length, '.') + i[1] + '\n'
     usage_text[context] = text
